pub struct ChildProcessPool {
pub assets_for_source_mapping: ResolvedVc<AssetsForSourceMapping>,
pub assets_root: FileSystemPath,
pub project_dir: FileSystemPath,
/* private fields */
}Expand description
A pool of Node.js workers operating on [entrypoint] with specific [cwd] and env.
The pool will spawn processes when needed and reuses old ones. It will never
spawn more then a certain number of concurrent processes. This is specified
with the concurrency argument in the constructor.
The worker will not use the env of the parent process by default. All env vars need to be provided to make the execution as pure as possible.
Fields
assets_for_source_mapping: ResolvedVc<AssetsForSourceMapping>assets_root: FileSystemPathproject_dir: FileSystemPathImplementations
Sourceimpl ChildProcessPool
impl ChildProcessPool
Sourcepub fn cell(self) -> Vc<Self>
pub fn cell(self) -> Vc<Self>
Places a value in a cell of the current task.
Cell is selected based on the value type and call order of cell.
Sourcepub fn resolved_cell(self) -> ResolvedVc<Self>
pub fn resolved_cell(self) -> ResolvedVc<Self>
Places a value in a cell of the current task. Returns a
ResolvedVc.
Cell is selected based on the value type and call order of cell.
Sourceimpl ChildProcessPool
impl ChildProcessPool
Sourcepub fn create(
cwd: PathBuf,
entrypoint: PathBuf,
env: FxHashMap<RcStr, RcStr>,
assets_for_source_mapping: ResolvedVc<AssetsForSourceMapping>,
assets_root: FileSystemPath,
project_dir: FileSystemPath,
concurrency: usize,
debug: bool,
) -> EvaluatePool
pub fn create( cwd: PathBuf, entrypoint: PathBuf, env: FxHashMap<RcStr, RcStr>, assets_for_source_mapping: ResolvedVc<AssetsForSourceMapping>, assets_root: FileSystemPath, project_dir: FileSystemPath, concurrency: usize, debug: bool, ) -> EvaluatePool
- debug: Whether to automatically enable Node’s
--inspect-brkwhen spawning it. Note: automatically overrides concurrency to 1.
Sourceimpl ChildProcessPool
impl ChildProcessPool
pub fn scale_down()
pub fn scale_zero()